@@ -1,10 +1,11 @@
-
+#include <config.h>
 #include "mpg123.h"
-//#include "audio.h"
+
 #include "esd-audio.h"
 #include <string.h>
 #include <stdlib.h>
 #include <pthread.h>
+#include <libgnome/gnome-i18n.h>
 
 static long outscale = 32768;
 
@@ -255,16 +256,14 @@ static gchar *eval_id3_format(const char *id3_format, struct id3tag_t *id3,
 	const size_t alloc_size = 256;	/* size of memory block allocations */
 	gboolean got_field = FALSE;
 
-	ans = g_malloc(allocated = alloc_size);
-	pathlen = strlen(path = g_dirname(filename));
-	base = g_strdup(g_basename(filename));
+	ans = g_malloc (allocated = alloc_size);
+	pathlen = strlen (path = g_path_get_dirname (filename));
+	base = g_path_get_basename (filename);
 	if ((ext = extname(base)) == NULL)
 	{
 		ext = "";
 		extlen = 0;
-	}
-	else
-	{
+	} else {
 		*(ext - 1) = '\0';
 		extlen = strlen(ext);
 	}
@@ -368,7 +367,7 @@ mpg123_id3v1_to_id3v2 (struct id3v1tag_t *v1, struct id3tag_t *v2)
 	strncpy(v2->album, v1->album, 30);
 	strncpy(v2->year, v1->year, 4);
 	strncpy(v2->comment, v1->comment, 28);
-	strncpy(v2->track, v1->track, 2);
+	g_snprintf(v2->track, sizeof v2->track, "%d", v1->track);
 	strncpy(v2->genre, get_id3_genre(v1->genre), sizeof (v2->genre));
 	mpg123_strip_spaces(v2->title, 30);
 	mpg123_strip_spaces(v2->artist, 30);
@@ -403,7 +402,7 @@ gchar *mpg123_format_song_title(struct id3tag_t *tag, gchar * filename)
 		/*
 		 * Format according to filename.
 		 */
-		ret = g_strdup(g_basename(filename));
+		ret = g_path_get_basename (filename);
 		if (extname(ret) != NULL)
 			*(extname(ret) - 1) = '\0';	/* removes period */
 	}
@@ -772,6 +771,7 @@ static void
 	g_free (mpg123_pcm_sample);
 
 	pthread_exit (NULL);
+	return NULL;  /* make GCC happy */
 }
 
 void 
