@@ -41,6 +41,7 @@
 #include <eel/eel-string.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtksignal.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 
 enum {
 	FILES_ADDED,
@@ -63,7 +64,6 @@ static guint signals[LAST_SIGNAL];
 static GHashTable *directories;
 
 static void               nautilus_directory_finalize         (GObject                *object);
-static void               nautilus_directory_dispose          (GObject                *object);
 static void               nautilus_directory_init             (gpointer                object,
 							       gpointer                klass);
 static void               nautilus_directory_class_init (NautilusDirectoryClass *klass);
@@ -84,7 +84,6 @@ nautilus_directory_class_init (NautilusDirectoryClass *klass)
 	object_class = G_OBJECT_CLASS (klass);
 	
 	object_class->finalize = nautilus_directory_finalize;
-	object_class->dispose  = nautilus_directory_dispose;
 
 	signals[FILES_ADDED] =
 		g_signal_new ("files_added",
@@ -92,7 +91,7 @@ nautilus_directory_class_init (NautilusDirectoryClass *klass)
 		              G_SIGNAL_RUN_LAST,
 		              G_STRUCT_OFFSET (NautilusDirectoryClass, files_added),
 		              NULL, NULL,
-		              gtk_marshal_VOID__POINTER,
+		              g_cclosure_marshal_VOID__POINTER,
 		              G_TYPE_NONE, 1, G_TYPE_POINTER);
 	signals[FILES_CHANGED] =
 		g_signal_new ("files_changed",
@@ -100,7 +99,7 @@ nautilus_directory_class_init (NautilusDirectoryClass *klass)
 		              G_SIGNAL_RUN_LAST,
 		              G_STRUCT_OFFSET (NautilusDirectoryClass, files_changed),
 		              NULL, NULL,
-		              gtk_marshal_VOID__POINTER,
+		              g_cclosure_marshal_VOID__POINTER,
 		              G_TYPE_NONE, 1, G_TYPE_POINTER);
 	signals[DONE_LOADING] =
 		g_signal_new ("done_loading",
@@ -108,7 +107,7 @@ nautilus_directory_class_init (NautilusDirectoryClass *klass)
 		              G_SIGNAL_RUN_LAST,
 		              G_STRUCT_OFFSET (NautilusDirectoryClass, done_loading),
 		              NULL, NULL,
-		              gtk_marshal_VOID__VOID,
+		              g_cclosure_marshal_VOID__VOID,
 		              G_TYPE_NONE, 0);
 	signals[LOAD_ERROR] =
 		g_signal_new ("load_error",
@@ -116,7 +115,7 @@ nautilus_directory_class_init (NautilusDirectoryClass *klass)
 		              G_SIGNAL_RUN_LAST,
 		              G_STRUCT_OFFSET (NautilusDirectoryClass, load_error),
 		              NULL, NULL,
-		              gtk_marshal_VOID__INT,
+		              g_cclosure_marshal_VOID__INT,
 		              G_TYPE_NONE, 1, G_TYPE_INT);
 
 	klass->get_name_for_self_as_new_file = real_get_name_for_self_as_new_file;
@@ -161,7 +160,7 @@ nautilus_directory_unref (NautilusDirectory *directory)
 }
 
 static void
-nautilus_directory_dispose (GObject *object)
+nautilus_directory_finalize (GObject *object)
 {
 	NautilusDirectory *directory;
 
@@ -176,46 +175,28 @@ nautilus_directory_dispose (GObject *object)
 	if (directory->details->monitor_list != NULL) {
 		g_warning ("destroying a NautilusDirectory while it's being monitored");
 		eel_g_list_free_deep (directory->details->monitor_list);
-		directory->details->monitor_list = NULL;
 	}
 
 	if (directory->details->monitor != NULL) {
 		nautilus_monitor_cancel (directory->details->monitor);
-		directory->details->monitor = NULL;
 	}
 
 	if (directory->details->metafile_monitor != NULL) {
 		nautilus_directory_unregister_metadata_monitor (directory);
-		directory->details->metafile_monitor = NULL;
 	}
 
-	directory->details->metafile_corba_object =
-		bonobo_object_release_unref (
-			directory->details->metafile_corba_object, NULL);
+	bonobo_object_release_unref (directory->details->metafile_corba_object, NULL);
 
 	if (directory->details->dequeue_pending_idle_id != 0) {
 		gtk_idle_remove (directory->details->dequeue_pending_idle_id);
-		directory->details->dequeue_pending_idle_id = 0;
 	}
  
 	g_free (directory->details->uri);
-	directory->details->uri = NULL;
 
 	if (directory->details->vfs_uri != NULL) {
 		gnome_vfs_uri_unref (directory->details->vfs_uri);
-		directory->details->vfs_uri = NULL;
 	}
 
-	EEL_CALL_PARENT (G_OBJECT_CLASS, dispose, (object));
-}
-
-static void
-nautilus_directory_finalize (GObject *object)
-{
-	NautilusDirectory *directory;
-
-	directory = NAUTILUS_DIRECTORY (object);
-
 	g_assert (directory->details->file_list == NULL);
 	g_hash_table_destroy (directory->details->file_hash);
 
@@ -262,7 +243,7 @@ emit_change_signals_for_all_files (NautilusDirectory *directory)
 {
 	GList *files;
 
-	files = eel_g_list_copy (directory->details->file_list);
+	files = g_list_copy (directory->details->file_list);
 	if (directory->details->as_file != NULL) {
 		files = g_list_prepend (files, directory->details->as_file);
 	}
@@ -302,6 +283,8 @@ async_data_preference_changed_callback (gpointer callback_data)
 static void
 add_preferences_callbacks (void)
 {
+	nautilus_global_preferences_init ();
+
 	eel_preferences_add_callback (NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES,
 				      filtering_changed_callback,
 				      NULL);
@@ -314,9 +297,6 @@ add_preferences_callbacks (void)
 	eel_preferences_add_callback (NAUTILUS_PREFERENCES_SHOW_DIRECTORY_ITEM_COUNTS,
 				      async_data_preference_changed_callback,
 				      NULL);
-	eel_preferences_add_callback (NAUTILUS_PREFERENCES_DEFAULT_SMOOTH_FONT,
-				      async_data_preference_changed_callback,
-				      NULL);
 }
 
 char *
@@ -423,6 +403,20 @@ nautilus_directory_get_existing (const char *uri)
 	return nautilus_directory_get_internal (uri, FALSE);
 }
 
+NautilusDirectory *
+nautilus_directory_get_for_file (NautilusFile *file)
+{
+	char *uri;
+	NautilusDirectory *directory;
+
+	g_return_val_if_fail (NAUTILUS_IS_FILE (file), NULL);
+
+	uri = nautilus_file_get_uri (file);
+	directory = nautilus_directory_get (uri);
+	g_free (uri);
+	return directory;
+}
+
 /* Returns a reffed NautilusFile object for this directory.
  */
 NautilusFile *
@@ -1017,7 +1011,7 @@ nautilus_directory_notify_files_removed (GList *uris)
 
 		/* Find the file. */
 		file = nautilus_file_get_existing (uri);
-		if (file != NULL) {
+		if (file != NULL && !nautilus_file_rename_in_progress (file)) {
 			/* Mark it gone and prepare to send the changed signal. */
 			nautilus_file_mark_gone (file);
 			hash_table_list_prepend (changed_lists,
@@ -1310,7 +1304,7 @@ nautilus_directory_schedule_metadata_copy (GList *uri_pairs)
 	GList *p;
 	URIPair *pair;
 	NautilusDirectory *source_directory, *destination_directory;
-	const char *source_relative_uri, *destination_relative_uri;
+	char *source_relative_uri, *destination_relative_uri;
 
 	for (p = uri_pairs; p != NULL; p = p->next) {
 		pair = (URIPair *) p->data;
@@ -1318,13 +1312,16 @@ nautilus_directory_schedule_metadata_copy (GList *uri_pairs)
 		source_directory = get_parent_directory (pair->from_uri);
 		destination_directory = get_parent_directory (pair->to_uri);
 		
-		source_relative_uri = g_basename (pair->from_uri);
-		destination_relative_uri = g_basename (pair->to_uri);
+		source_relative_uri = g_path_get_basename (pair->from_uri);
+		destination_relative_uri = g_path_get_basename (pair->to_uri);
 		
 		nautilus_directory_copy_file_metadata (source_directory,
 						       source_relative_uri,
 						       destination_directory,
 						       destination_relative_uri);
+
+		g_free (source_relative_uri);
+		g_free (destination_relative_uri);
 		
 		nautilus_directory_unref (source_directory);
 		nautilus_directory_unref (destination_directory);
@@ -1337,7 +1334,7 @@ nautilus_directory_schedule_metadata_move (GList *uri_pairs)
 	GList *p;
 	URIPair *pair;
 	NautilusDirectory *source_directory, *destination_directory;
-	const char *source_relative_uri, *destination_relative_uri;
+	char *source_relative_uri, *destination_relative_uri;
 
 	for (p = uri_pairs; p != NULL; p = p->next) {
 		pair = (URIPair *) p->data;
@@ -1345,8 +1342,8 @@ nautilus_directory_schedule_metadata_move (GList *uri_pairs)
 		source_directory = get_parent_directory (pair->from_uri);
 		destination_directory = get_parent_directory (pair->to_uri);
 		
-		source_relative_uri = g_basename (pair->from_uri);
-		destination_relative_uri = g_basename (pair->to_uri);
+		source_relative_uri = g_path_get_basename (pair->from_uri);
+		destination_relative_uri = g_path_get_basename (pair->to_uri);
 		
 		nautilus_directory_copy_file_metadata (source_directory,
 						       source_relative_uri,
@@ -1355,6 +1352,9 @@ nautilus_directory_schedule_metadata_move (GList *uri_pairs)
 		nautilus_directory_remove_file_metadata (source_directory,
 							 source_relative_uri);
 		
+		g_free (source_relative_uri);
+		g_free (destination_relative_uri);
+
 		nautilus_directory_unref (source_directory);
 		nautilus_directory_unref (destination_directory);
 	}
@@ -1366,16 +1366,18 @@ nautilus_directory_schedule_metadata_remove (GList *uris)
 	GList *p;
 	const char *uri;
 	NautilusDirectory *directory;
-	const char *relative_uri;
+	char *relative_uri;
 
 	for (p = uris; p != NULL; p = p->next) {
 		uri = (const char *) p->data;
 
 		directory = get_parent_directory (uri);
-		relative_uri = g_basename (uri);
+		relative_uri = g_path_get_basename (uri);
 		
 		nautilus_directory_remove_file_metadata (directory,
 							 relative_uri);
+
+		g_free (relative_uri);
 		
 		nautilus_directory_unref (directory);
 	}
