@@ -244,7 +244,7 @@ fm_icon_view_finalize (GObject *object)
 
 	if (icon_view->details->ui != NULL) {
 		bonobo_ui_component_unset_container (icon_view->details->ui, NULL);
-		bonobo_object_unref (BONOBO_OBJECT (icon_view->details->ui));
+		bonobo_object_unref (icon_view->details->ui);
 	}
 
         if (icon_view->details->react_to_icon_change_idle_id != 0) {
@@ -1686,8 +1686,15 @@ preview_audio (FMIconView *icon_view, NautilusFile *file, gboolean start_flag)
 static gboolean
 should_preview_sound (NautilusFile *file) {
 
+	GConfClient *client;
+	gboolean enable_esd = FALSE;
+        
+	client = gconf_client_get_default ();
+	enable_esd = gconf_client_get_bool (client, "/desktop/gnome/sound/enable_esd", NULL);
+	g_object_unref (G_OBJECT (client));
+
 	/* Check gnome config sound preference */
-	if (!gnome_config_get_bool ("/sound/system/settings/start_esd=true")) {
+	if (!enable_esd) {
 		return FALSE;
 	}
 
@@ -2329,8 +2336,6 @@ fm_icon_view_update_icon_container_fonts (FMIconView *icon_view)
 	nautilus_icon_container_set_font_name (icon_container, font_name);
 
 	g_free (font_name);
-	
-	nautilus_icon_container_request_update_all (icon_container);
 }
 
 static int default_zoom_level_font_size = 12;
