@@ -89,6 +89,15 @@ list_activate_callback (GtkTreeView *tree_view, GtkTreePath *path, GtkTreeViewCo
 	nautilus_file_list_free (file_list);
 }
 
+static void
+event_after_callback (GtkWidget *widget, GdkEventAny *event, gpointer callback_data)
+{
+	if (event->type == GDK_BUTTON_PRESS && ((GdkEventButton *) event)->button == 3) {
+		fm_directory_view_pop_up_selection_context_menu
+			(FM_DIRECTORY_VIEW (callback_data), (GdkEventButton *) event);
+	}
+}
+
 static void
 create_and_set_up_tree_view (FMListView *view)
 {
@@ -101,6 +110,8 @@ create_and_set_up_tree_view (FMListView *view)
 
 	g_signal_connect (view->details->tree_view, "row_activated",
 			  G_CALLBACK (list_activate_callback), view);
+	g_signal_connect (view->details->tree_view, "event-after",
+			  G_CALLBACK (event_after_callback), view);
 	
 	view->details->model = g_object_new (FM_TYPE_LIST_MODEL, NULL);
 	gtk_tree_view_set_model (view->details->tree_view, GTK_TREE_MODEL (view->details->model));
@@ -180,25 +191,20 @@ set_sort_order_from_metadata_and_preferences (FMListView *list_view)
 	NautilusFile *file;
 	gboolean sort_reversed;
 	
-	sort_attribute = NULL;
-	
 	file = fm_directory_view_get_directory_as_file (FM_DIRECTORY_VIEW (list_view));
-
-	nautilus_file_get_metadata (file,
-				    NAUTILUS_METADATA_KEY_LIST_VIEW_SORT_COLUMN,
-				    sort_attribute);
-
-	if (sort_attribute == NULL) {
-		sort_column_id = fm_list_model_get_sort_column_id_from_sort_type (default_sort_order_auto_value);
-	} else {
-		sort_column_id = fm_list_model_get_sort_column_id_from_attribute (sort_attribute);
-	}
-	
+	sort_attribute = nautilus_file_get_metadata (file,
+						     NAUTILUS_METADATA_KEY_LIST_VIEW_SORT_COLUMN,
+						     NULL);
+	sort_column_id = fm_list_model_get_sort_column_id_from_attribute (sort_attribute);
 	g_free (sort_attribute);
 
+	if (sort_column_id == -1) {
+		sort_column_id = fm_list_model_get_sort_column_id_from_sort_type (default_sort_order_auto_value);
+	}
+
 	sort_reversed = nautilus_file_get_boolean_metadata (file,
-						       NAUTILUS_METADATA_KEY_LIST_VIEW_SORT_REVERSED,
-						       default_sort_reversed_auto_value);
+							    NAUTILUS_METADATA_KEY_LIST_VIEW_SORT_REVERSED,
+							    default_sort_reversed_auto_value);
 
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (list_view->details->model),
 					      sort_column_id,
@@ -284,24 +290,53 @@ fm_list_view_remove_file (FMDirectoryView *view, NautilusFile *file)
 static void
 fm_list_view_set_selection (FMDirectoryView *view, GList *selection)
 {
-	GList *list;
-	GtkTreeIter iter;
 	FMListView *list_view;
+	GtkTreeSelection *tree_selection;
+	GList *node;
+	GtkTreeIter iter;
 	NautilusFile *file;
 	
 	list_view = FM_LIST_VIEW (view);
+	tree_selection = gtk_tree_view_get_selection (list_view->details->tree_view);
 
-	gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (list_view->details->tree_view));
-
-	for (list = selection; list; list = list->next) {
-		file = list->data;
+	gtk_tree_selection_unselect_all (tree_selection);
+	for (node = selection; node != NULL; node = node->next) {
+		file = node->data;
 		if (fm_list_model_get_tree_iter_from_file (list_view->details->model, file, &iter)) {
-			gtk_tree_selection_select_iter (gtk_tree_view_get_selection (list_view->details->tree_view), &iter);
+			gtk_tree_selection_select_iter (tree_selection, &iter);
 		}
 	}
 }
 
-#if 0
+static void
+fm_list_view_select_all (FMDirectoryView *view)
+{
+	gtk_tree_selection_select_all (gtk_tree_view_get_selection (FM_LIST_VIEW (view)->details->tree_view));
+}
+
+/* Reset sort criteria and zoom level to match defaults */
+static void
+fm_list_view_reset_to_defaults (FMDirectoryView *view)
+{
+	NautilusFile *file;
+
+	file = fm_directory_view_get_directory_as_file (view);
+	nautilus_file_set_metadata (file, NAUTILUS_METADATA_KEY_LIST_VIEW_SORT_COLUMN, NULL, NULL);
+	nautilus_file_set_metadata (file, NAUTILUS_METADATA_KEY_LIST_VIEW_SORT_REVERSED, NULL, NULL);
+
+	gtk_tree_sortable_set_sort_column_id
+		(GTK_TREE_SORTABLE (FM_LIST_VIEW (view)->details->model),
+		 fm_list_model_get_sort_column_id_from_sort_type (default_sort_order_auto_value),
+		 default_sort_reversed_auto_value ? GTK_SORT_ASCENDING : GTK_SORT_DESCENDING);
+        fm_directory_view_restore_default_zoom_level (view);
+}
+
+#if GNOME2_CONVERSION_COMPLETE
+
+/* This is needed when writing out the sort to metadata. But we don't
+ * need this list here. We can probably do this using the table inside
+ * FMListModel.
+ */
 
 static char *
 get_attribute_from_sort_type (NautilusFileSortType sort_type)
@@ -355,24 +390,32 @@ fm_list_view_finalize (GObject *object)
 }
 
 static void
-fm_list_view_class_init (FMListViewClass *klass)
+fm_list_view_class_init (FMListViewClass *class)
 {
 	FMDirectoryViewClass *fm_directory_view_class;
-	GObjectClass *gobject_class;
 
-	gobject_class = (GObjectClass *)klass;
-	fm_directory_view_class = (FMDirectoryViewClass *)klass;
+	fm_directory_view_class = FM_DIRECTORY_VIEW_CLASS (class);
+
+	G_OBJECT_CLASS (class)->finalize = fm_list_view_finalize;
 
-	gobject_class->finalize = fm_list_view_finalize;
-	
 	fm_directory_view_class->add_file = fm_list_view_add_file;
 	fm_directory_view_class->begin_loading = fm_list_view_begin_loading;
+#if GNOME2_CONVERSION_COMPLETE
+	fm_directory_view_class->bump_zoom_level = xxx;
+	fm_directory_view_class->can_zoom_in = xxx;
+	fm_directory_view_class->can_zoom_out = xxx;
+#endif
 	fm_directory_view_class->clear = fm_list_view_clear;
 	fm_directory_view_class->file_changed = fm_list_view_file_changed;
 	fm_directory_view_class->get_background_widget = fm_list_view_get_background_widget;
 	fm_directory_view_class->get_selection = fm_list_view_get_selection;
 	fm_directory_view_class->is_empty = fm_list_view_is_empty;
+	fm_directory_view_class->reset_to_defaults = fm_list_view_reset_to_defaults;
+#if GNOME2_CONVERSION_COMPLETE
+	fm_directory_view_class->restore_default_zoom_level = xxx;
+#endif
 	fm_directory_view_class->remove_file = fm_list_view_remove_file;
+	fm_directory_view_class->select_all = fm_list_view_select_all;
 	fm_directory_view_class->set_selection = fm_list_view_set_selection;
 	fm_directory_view_class->sort_directories_first_changed = fm_list_view_sort_directories_first_changed;
 	
