@@ -31,16 +31,15 @@
 #include "nautilus-switchable-navigation-bar.h"
 
 #include "nautilus-switchable-search-bar.h"
+#include <bonobo/bonobo-dock.h>
+#include <eel/eel-gtk-macros.h>
+#include <eel/eel-string.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtkvbox.h>
-#include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-i18n.h>
-#include <libgnomeui/gnome-dock.h>
 #include <libnautilus-private/nautilus-directory.h>
-#include <eel/eel-gtk-macros.h>
 #include <libnautilus-private/nautilus-search-uri.h>
-#include <eel/eel-string.h>
 #include <stdio.h>
 
 struct NautilusSwitchableNavigationBarDetails {
@@ -48,6 +47,9 @@ struct NautilusSwitchableNavigationBarDetails {
 
 	NautilusLocationBar *location_bar;
 	NautilusSwitchableSearchBar *search_bar;
+	
+	NautilusWindow *window;
+	GtkWidget *hbox;
 };
 
 enum {
@@ -60,91 +62,99 @@ static guint signals[LAST_SIGNAL];
 static char *nautilus_switchable_navigation_bar_get_location     (NautilusNavigationBar                *bar);
 static void  nautilus_switchable_navigation_bar_set_location     (NautilusNavigationBar                *bar,
 								  const char                           *location);
-static void  nautilus_switchable_navigation_bar_initialize_class (NautilusSwitchableNavigationBarClass *class);
-static void  nautilus_switchable_navigation_bar_initialize       (NautilusSwitchableNavigationBar      *bar);
-static void  nautilus_switchable_navigation_bar_destroy 	 (GtkObject 			       *object);
+static void  nautilus_switchable_navigation_bar_class_init (NautilusSwitchableNavigationBarClass *class);
+static void  nautilus_switchable_navigation_bar_init       (NautilusSwitchableNavigationBar      *bar);
+static void  nautilus_switchable_navigation_bar_finalize 	 (GObject 			       *object);
 
-EEL_DEFINE_CLASS_BOILERPLATE (NautilusSwitchableNavigationBar,
+EEL_CLASS_BOILERPLATE (NautilusSwitchableNavigationBar,
 				   nautilus_switchable_navigation_bar,
 				   NAUTILUS_TYPE_NAVIGATION_BAR)
 
 static void
-nautilus_switchable_navigation_bar_initialize_class (NautilusSwitchableNavigationBarClass *klass)
+nautilus_switchable_navigation_bar_class_init (NautilusSwitchableNavigationBarClass *klass)
 {
 	
-	GtkObjectClass *object_class;
+	GObjectClass *gobject_class;
 	NautilusNavigationBarClass *navigation_bar_class;
 
-	object_class = GTK_OBJECT_CLASS (klass);
+	gobject_class = G_OBJECT_CLASS (klass);
 	navigation_bar_class = NAUTILUS_NAVIGATION_BAR_CLASS (klass);
 
-	signals[MODE_CHANGED] = gtk_signal_new
+	signals[MODE_CHANGED] = g_signal_new
 		("mode_changed",
-		 GTK_RUN_LAST,
-		 object_class->type,
-		 GTK_SIGNAL_OFFSET (NautilusSwitchableNavigationBarClass,
+		 G_TYPE_FROM_CLASS (gobject_class),
+		 G_SIGNAL_RUN_LAST,
+		 G_STRUCT_OFFSET (NautilusSwitchableNavigationBarClass,
 				    mode_changed),
-		 gtk_marshal_NONE__STRING,
-		 GTK_TYPE_NONE, 1, GTK_TYPE_INT);
-
-	gtk_object_class_add_signals (object_class, signals, LAST_SIGNAL);
+		 NULL, NULL,
+		 g_cclosure_marshal_VOID__STRING,
+		 G_TYPE_NONE, 1, G_TYPE_INT);
 	
-	object_class->destroy = nautilus_switchable_navigation_bar_destroy;
+	gobject_class->finalize = nautilus_switchable_navigation_bar_finalize;
 
 	navigation_bar_class->get_location = nautilus_switchable_navigation_bar_get_location;
 	navigation_bar_class->set_location = nautilus_switchable_navigation_bar_set_location;
 }
 
 static void
-nautilus_switchable_navigation_bar_initialize (NautilusSwitchableNavigationBar *bar)
+nautilus_switchable_navigation_bar_init (NautilusSwitchableNavigationBar *bar)
 {
 
-
-
 	bar->details = g_new0 (NautilusSwitchableNavigationBarDetails, 1);
 
-
 }
 
 static void
-nautilus_switchable_navigation_bar_destroy (GtkObject *object)
+nautilus_switchable_navigation_bar_finalize (GObject *object)
 {
 	g_free (NAUTILUS_SWITCHABLE_NAVIGATION_BAR (object)->details);
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	
+	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
+static void
+create_search_bar_if_non_existant (NautilusSwitchableNavigationBar *bar)
+{
+	if (bar->details->search_bar != NULL) {
+		return;
+	}
+
+	bar->details->search_bar = NAUTILUS_SWITCHABLE_SEARCH_BAR (nautilus_switchable_search_bar_new (bar->details->window));
+
+	g_signal_connect_swapped (bar->details->search_bar,
+				  "location_changed",
+				   G_CALLBACK (nautilus_navigation_bar_location_changed),
+				   bar);
+
+	gtk_box_pack_start (GTK_BOX (bar->details->hbox), GTK_WIDGET (bar->details->search_bar), TRUE, TRUE, 0);
+}
+
+
 GtkWidget *
 nautilus_switchable_navigation_bar_new (NautilusWindow *window)
 {
 	GtkWidget *bar;
-	GtkWidget *hbox;
 	NautilusSwitchableNavigationBar *switchable_navigation_bar;
 	
 	bar = gtk_widget_new (NAUTILUS_TYPE_SWITCHABLE_NAVIGATION_BAR, NULL);
 
-	hbox = gtk_hbox_new (FALSE, 0);
-
 	switchable_navigation_bar = NAUTILUS_SWITCHABLE_NAVIGATION_BAR (bar);
-	switchable_navigation_bar->details->location_bar = NAUTILUS_LOCATION_BAR (nautilus_location_bar_new (window));
-	switchable_navigation_bar->details->search_bar = NAUTILUS_SWITCHABLE_SEARCH_BAR (nautilus_switchable_search_bar_new (window));
 
-	gtk_signal_connect_object (GTK_OBJECT (switchable_navigation_bar->details->location_bar),
-				   "location_changed",
-				   nautilus_navigation_bar_location_changed,
-				   GTK_OBJECT (bar));
-	gtk_signal_connect_object (GTK_OBJECT (switchable_navigation_bar->details->search_bar),
-				   "location_changed",
-				   nautilus_navigation_bar_location_changed,
-				   GTK_OBJECT (bar));
+	switchable_navigation_bar->details->hbox = gtk_hbox_new (FALSE, 0);
+	switchable_navigation_bar->details->window = window;
+	switchable_navigation_bar->details->location_bar = NAUTILUS_LOCATION_BAR (nautilus_location_bar_new (window));
+
+	g_signal_connect_swapped (switchable_navigation_bar->details->location_bar,
+				  "location_changed",
+				  G_CALLBACK (nautilus_navigation_bar_location_changed),
+				  bar);
 	
-	gtk_box_pack_start  (GTK_BOX (hbox), GTK_WIDGET (switchable_navigation_bar->details->location_bar), TRUE, TRUE,
-			     0);
-	gtk_box_pack_start  (GTK_BOX (hbox), GTK_WIDGET (switchable_navigation_bar->details->search_bar), TRUE, TRUE,
-			     0);
+	gtk_box_pack_start  (GTK_BOX (switchable_navigation_bar->details->hbox),
+			     GTK_WIDGET (switchable_navigation_bar->details->location_bar), TRUE, TRUE, 0);
 
 	gtk_widget_show (GTK_WIDGET (switchable_navigation_bar->details->location_bar));
-	gtk_widget_show (GTK_WIDGET (hbox));
-	gtk_container_add (GTK_CONTAINER (bar), hbox);
+	gtk_widget_show (GTK_WIDGET (switchable_navigation_bar->details->hbox));
+	gtk_container_add (GTK_CONTAINER (bar), switchable_navigation_bar->details->hbox);
 
 	return bar;
 }
@@ -194,6 +204,10 @@ nautilus_switchable_navigation_bar_set_mode (NautilusSwitchableNavigationBar
 		widget_to_hide = GTK_WIDGET (bar->details->search_bar);
 		break;
 	case NAUTILUS_SWITCHABLE_NAVIGATION_BAR_MODE_SEARCH:
+
+		/* If the search bar hasn't been created, create it */
+		create_search_bar_if_non_existant (bar);
+		
 		widget_to_show = GTK_WIDGET (bar->details->search_bar);
 		widget_to_hide = GTK_WIDGET (bar->details->location_bar);
 		break;
@@ -202,22 +216,25 @@ nautilus_switchable_navigation_bar_set_mode (NautilusSwitchableNavigationBar
 	}
 
 	gtk_widget_show (widget_to_show);
-	gtk_widget_hide (widget_to_hide);
+
+	if (widget_to_hide != NULL) {
+		gtk_widget_hide (widget_to_hide);
+	}
 
 	nautilus_switchable_navigation_bar_activate (bar);
 
-	/* FIXME bugzilla.eazel.com 3171:
+	/* FIXME bugzilla.gnome.org 43171:
 	 * We don't know why this line is needed here, but if it's removed
 	 * then the bar won't shrink when we switch from the complex search
 	 * bar to the location bar (though it does grow when switching in
 	 * the other direction)
 	 */
-	dock = gtk_widget_get_ancestor (GTK_WIDGET (bar), GNOME_TYPE_DOCK);
+	dock = gtk_widget_get_ancestor (GTK_WIDGET (bar), BONOBO_TYPE_DOCK);
 	if (dock != NULL) {
 		gtk_widget_queue_resize (dock);
 	}
 
-	gtk_signal_emit (GTK_OBJECT (bar), signals[MODE_CHANGED], mode);
+	g_signal_emit (bar, signals[MODE_CHANGED], 0, mode);
 }
 
 static char *
@@ -251,8 +268,11 @@ nautilus_switchable_navigation_bar_set_location (NautilusNavigationBar *navigati
 	 */
 	nautilus_navigation_bar_set_location (NAUTILUS_NAVIGATION_BAR (bar->details->location_bar),
 					      location);
-	nautilus_navigation_bar_set_location (NAUTILUS_NAVIGATION_BAR (bar->details->search_bar),
-					      location);
+
+	if (bar->details->search_bar != NULL) {
+		nautilus_navigation_bar_set_location (NAUTILUS_NAVIGATION_BAR (bar->details->search_bar),
+						      location);
+	}
 	
 	/* Toggle the search button on and off appropriately */
 	if (nautilus_is_search_uri (location)) {
