@@ -70,7 +70,7 @@ activate_back_or_forward_menu_item (GtkMenuItem *menu_item,
 	g_assert (GTK_IS_MENU_ITEM (menu_item));
 	g_assert (NAUTILUS_IS_WINDOW (window));
 
-	index = GPOINTER_TO_INT (gtk_object_get_user_data (GTK_OBJECT (menu_item)));
+	index = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (menu_item), "user_data"));
 	nautilus_window_back_or_forward (window, back, index);
 }
 
@@ -103,17 +103,17 @@ create_back_or_forward_menu (NautilusWindow *window, gboolean back)
 	while (list_link != NULL)
 	{
 		menu_item = nautilus_bookmark_menu_item_new (NAUTILUS_BOOKMARK (list_link->data));		
-		gtk_object_set_user_data (GTK_OBJECT (menu_item), GINT_TO_POINTER (index));
+		g_object_set_data (G_OBJECT (menu_item), "user_data", GINT_TO_POINTER (index));
 		gtk_widget_show (GTK_WIDGET (menu_item));
-  		gtk_signal_connect
-			(GTK_OBJECT(menu_item), 
+  		g_signal_connect
+			(menu_item,
 			 "activate",
 			 back
 			 ? G_CALLBACK (activate_back_menu_item_callback)
 			 : G_CALLBACK (activate_forward_menu_item_callback),
 			 window);
 		
-		gtk_menu_append (menu, menu_item);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 		list_link = g_list_next (list_link);
 		++index;
 	}
@@ -224,11 +224,11 @@ static void
 set_up_standard_bonobo_button (NautilusWindow *window, 
 			       const char *item_path, 
 			       const char *icon_name,
-			       gboolean is_custom)
+			       const char *stock_item_fallback)
 {
 	char *file_name;
 
-	file_name = get_file_name_from_icon_name (icon_name, is_custom);
+	file_name = get_file_name_from_icon_name (icon_name, (stock_item_fallback == NULL));
 		
 	/* set up the toolbar component with the new image */
 	bonobo_ui_component_set_prop (window->details->shell_ui, 
@@ -239,7 +239,7 @@ set_up_standard_bonobo_button (NautilusWindow *window,
 	bonobo_ui_component_set_prop (window->details->shell_ui, 
 				      item_path,
 				      "pixname",
-				      file_name == NULL ? icon_name : file_name,
+				      file_name == NULL ? stock_item_fallback : file_name,
 			      	      NULL);
 
 	g_free (file_name);
@@ -252,22 +252,32 @@ static void
 set_up_special_bonobo_button (NautilusWindow            *window,
 			      BonoboUIToolbarButtonItem *item,
 			      const char                *control_path,
-			      const char                *icon_name)
+			      const char                *icon_name,
+			      const char                *stock_item_fallback)
 {
 	char *icon_file_name;
-	GdkPixbuf *pixbuf;	
+	GtkWidget *image;
+	GtkStockItem stock_item;
+
+	image = NULL;
 
 	icon_file_name = get_file_name_from_icon_name (icon_name, FALSE);
 
 	if (icon_file_name == NULL) {
-		return;
+		if (gtk_stock_lookup (stock_item_fallback, &stock_item)) {
+			image = gtk_image_new_from_stock (stock_item_fallback, 
+							  GTK_ICON_SIZE_BUTTON);
+		}
+	} else {
+		image = gtk_image_new_from_file (icon_file_name);
+		g_free (icon_file_name);
 	}
 
-	pixbuf = gdk_pixbuf_new_from_file (icon_file_name, NULL);
-	g_free (icon_file_name);
+	if (image == NULL) {
+		return;
+	}
 	
-	bonobo_ui_toolbar_button_item_set_image (item, pixbuf);
-	g_object_unref (pixbuf);
+	bonobo_ui_toolbar_button_item_set_image (item, image);
 }			      
 
 static void
@@ -277,15 +287,16 @@ set_up_toolbar_images (NautilusWindow *window)
 
 	bonobo_ui_component_freeze (window->details->shell_ui, NULL);
 
-	set_up_special_bonobo_button (window, window->details->back_button_item, "/Toolbar/BackWrapper", "Back");
-	set_up_special_bonobo_button (window, window->details->forward_button_item, "/Toolbar/ForwardWrapper", "Forward");
+	set_up_special_bonobo_button (window, window->details->back_button_item, 
+				      "/Toolbar/BackWrapper", "Back", GTK_STOCK_GO_BACK);
+	set_up_special_bonobo_button (window, window->details->forward_button_item, 
+				      "/Toolbar/ForwardWrapper", "Forward", GTK_STOCK_GO_FORWARD);
 	
-	set_up_standard_bonobo_button (window, "/Toolbar/Up", "Up", FALSE);
-	set_up_standard_bonobo_button (window, "/Toolbar/Home", "Home", FALSE);
-	set_up_standard_bonobo_button (window, "/Toolbar/Reload", "Refresh", FALSE);
-	set_up_standard_bonobo_button (window, "/Toolbar/Toggle Find Mode", "Search", FALSE);
-	set_up_standard_bonobo_button (window, "/Toolbar/Go to Web Search", "SearchWeb", TRUE);
-	set_up_standard_bonobo_button (window, "/Toolbar/Stop", "Stop", FALSE);
+	set_up_standard_bonobo_button (window, "/Toolbar/Up", "Up", GTK_STOCK_GO_UP);
+	set_up_standard_bonobo_button (window, "/Toolbar/Home", "Home", GTK_STOCK_HOME);
+	set_up_standard_bonobo_button (window, "/Toolbar/Reload", "Refresh", GTK_STOCK_REFRESH);
+	set_up_standard_bonobo_button (window, "/Toolbar/Toggle Find Mode", "Search", GTK_STOCK_FIND);
+	set_up_standard_bonobo_button (window, "/Toolbar/Stop", "Stop", GTK_STOCK_STOP);
 
 	bonobo_ui_component_thaw (window->details->shell_ui, NULL);
 
@@ -380,14 +391,14 @@ create_back_or_forward_toolbar_item (NautilusWindow *window,
 				 _("Toolbar item orientation"),
 				 Bonobo_PROPERTY_WRITEABLE);
 	bonobo_control_set_properties (wrapper, BONOBO_OBJREF (pb), NULL);
-	bonobo_object_unref (BONOBO_OBJECT (pb));
+	bonobo_object_unref (pb);
 
 	bonobo_ui_component_object_set (window->details->shell_ui,
 					control_path,
 					BONOBO_OBJREF (wrapper),
 					NULL);
 
-	bonobo_object_unref (BONOBO_OBJECT (wrapper));
+	bonobo_object_unref (wrapper);
 
 	return item;
 }
